@@ -80,7 +80,7 @@
 #' simulation}
 #'
 #' The output should be accessed using the function
-#' \code{\link{get_RLum.Results}}
+#' \code{\link{get_RLum}}
 #' @section Function version: 0.31
 #' @author Christoph Burow, University of Cologne (Germany)
 #' @references Duller, G.A.T., 2008. Single-grain optical dating of Quaternary
@@ -387,7 +387,8 @@ calc_AliquotSize <- function(
   args<- list(grain.size = grain.size, sample.diameter = sample.diameter, packing.density = packing.density, MC = MC, grains.counted = grains.counted, MC.iter=MC.iter)
 
   # create S4 object
-  newRLumResults.calc_AliquotSize <- set_RLum.Results(
+  newRLumResults.calc_AliquotSize <- set_RLum(
+    class = "RLum.Results",
     data = list(
       summary=summary,
       args=args,
