@@ -100,7 +100,7 @@
 #' \item{bootstrap}{\link{list} bootstrap results}
 #'
 #' The output should be accessed using the function
-#' \code{\link{get_RLum.Results}}
+#' \code{\link{get_RLum}}
 #' @note The default starting values for \emph{gamma}, \emph{mu}, \emph{sigma}
 #' and \emph{p0} may only be appropriate for some De data sets and may need to
 #' be changed for other data. This is especially true when the un-logged
@@ -162,7 +162,7 @@
 #' mam
 #'
 #' # Show summary table that contains the most relevant results
-#' res <- get_RLum.Results(mam, "summary")
+#' res <- get_RLum(mam, "summary")
 #' res
 #'
 #' # Plot the log likelihood profiles retroactively, because before
@@ -214,7 +214,7 @@
 #' #plot_RLum(mam)
 #'
 #' # save bootstrap results in a separate variable
-#' #bs <- get_RLum.Results(mam, "bootstrap")
+#' #bs <- get_RLum(mam, "bootstrap")
 #'
 #' # show structure of the bootstrap results
 #' #str(bs, max.level = 2, give.attr = FALSE)
@@ -757,7 +757,8 @@ calc_MinDose <- function(
   if (!bootstrap)
     pairs <- poly.three <- poly.four <- poly.five <- poly.six <- loess <- NULL
 
-  newRLumResults.calc_MinDose <- set_RLum.Results(
+  newRLumResults.calc_MinDose <- set_RLum(
+    class = "RLum.Results",
     data = list(summary = summary,
                 data = data,
                 args = args,
