@@ -100,71 +100,71 @@ plot_Histogram <- function(
   colour,
   ...
 ) {
-
+  
   # Integrity tests ---------------------------------------------------------
   ## check/adjust input data structure
   if(is(data, "RLum.Results") == FALSE &
-       is(data, "data.frame") == FALSE) {
-
+     is(data, "data.frame") == FALSE) {
+    
     stop(paste("[plot_Histogram()] Input data format is neither",
                "'data.frame' nor 'RLum.Results'"))
   } else {
-
+    
     if(is(data, "RLum.Results") == TRUE) {
-      data <- get_RLum.Results(data)[,1:2]
+      data <- get_RLum(data, "data")
     }
   }
-
+  
   ## handle error-free data sets
   if(length(data) < 2) {
     data <- cbind(data, rep(NA, length(data)))
   }
-
-
+  
+  
   ## Set general parameters ---------------------------------------------------
   ## Check/set default parameters
   if(missing(cex.global) == TRUE) {
     cex.global <- 1
   }
-
+  
   if(missing(mtext) == TRUE) {
     mtext <- ""
   }
-
+  
   if(missing(se) == TRUE) {
     se = TRUE
   }
-
+  
   if(missing(rug) == TRUE) {
     rug = TRUE
   }
-
+  
   if(missing(colour) == TRUE) {
     colour = c("white", "black", "red", "black")
   }
-
+  
   if(missing(summary) == TRUE) {
     summary <- ""
   }
-
+  
   if(missing(summary.pos) == TRUE) {
     summary.pos <- "sub"
   }
-
+  
   if(missing(normal_curve) == TRUE) {
     normal_curve = FALSE
   }
-
+  
   ## read out additional arguments list
   extraArgs <- list(...)
-
+  
   ## define fun
   if("fun" %in% names(extraArgs)) {
     fun <- extraArgs$fun
   } else {
     fun <- FALSE
   }
-
+  
   ## optionally, count and exclude NA values and print result
   if(na.rm == TRUE) {
     n.NA <- sum(is.na(data[,1]))
@@ -175,39 +175,39 @@ plot_Histogram <- function(
     }
     data <- data[!is.na(data[,1]),]
   }
-
+  
   if("main" %in% names(extraArgs)) {
     main.plot <- extraArgs$main
   } else {
     main.plot <- "Histogram"
   }
-
+  
   if("xlab" %in% names(extraArgs)) {
     xlab.plot <- extraArgs$xlab
   } else {
     xlab.plot <- expression(paste(D[e], " (Gy)"))
   }
-
+  
   if("ylab" %in% names(extraArgs)) {
     ylab.plot <- extraArgs$ylab
   } else {
     ylab.plot <- c("Frequency",
                    "Standard error")
   }
-
+  
   if("breaks" %in% names(extraArgs)) {
     breaks.plot <- extraArgs$breaks
   } else {
     breaks.plot <- hist(x = data[,1],
                         plot = FALSE)$breaks
   }
-
+  
   if("xlim" %in% names(extraArgs)) {
     xlim.plot <- extraArgs$xlim
   } else {
     xlim.plot <- range(breaks.plot)
   }
-
+  
   if("ylim" %in% names(extraArgs)) {
     ylim.plot <- extraArgs$ylim
   } else {
@@ -225,7 +225,7 @@ plot_Histogram <- function(
     range.error[2] <- ifelse(is.infinite(range.error[2]), 0, range.error[2])
     ylim.plot <- c(left.ylim, range.error)
   }
-
+  
   if("pch" %in% names(extraArgs)) {
     pch.plot <- extraArgs$pch
   } else {
@@ -234,7 +234,7 @@ plot_Histogram <- function(
   ## Set plot area format
   par(mar = c(4.5, 4.5, 4.5, 4.5),
       cex = cex.global)
-
+  
   ## Plot histogram -----------------------------------------------------------
   HIST <- hist(data[,1],
                main = "",
@@ -246,20 +246,20 @@ plot_Histogram <- function(
                freq = !normal_curve,
                col = colour[1]
   )
-
+  
   ## add title
   title(line = 2,
         main = main.plot)
-
+  
   ## Optionally, add rug ------------------------------------------------------
   if(rug == TRUE) {rug(data[,1], col = colour[2])}
-
+  
   ## Optionally, add a normal curve based on the data -------------------------
   if(normal_curve == TRUE){
     ## cheat the R check routine, tztztz how neat
     x <- NULL
     rm(x)
-
+    
     ## add normal distribution curve
     curve(dnorm(x,
                 mean = mean(na.exclude(data[,1])),
@@ -268,10 +268,10 @@ plot_Histogram <- function(
           add = TRUE,
           lwd = 1.2 * cex.global)
   }
-
+  
   ## calculate and paste statistical summary
   data.stats <- list(data = data)
-
+  
   ## calculate and paste statistical summary
   De.stats <- matrix(nrow = length(data), ncol = 18)
   colnames(De.stats) <- c("n",
@@ -321,7 +321,7 @@ plot_Histogram <- function(
     
     De.stats[i,6] <- De.density$x[which.max(De.density$y)]
   }
-
+  
   label.text = list(NA)
   
   if(summary.pos[1] != "sub") {
@@ -555,7 +555,7 @@ plot_Histogram <- function(
         summary.text,
         sep = "")
     }
-
+    
     ## remove outer vertical lines from string
     for(i in 2:length(label.text)) {
       label.text[[i]] <- substr(x = label.text[[i]],
@@ -563,10 +563,10 @@ plot_Histogram <- function(
                                 stop = nchar(label.text[[i]]) - 3)
     }
   }
-
+  
   ## remove dummy list element
   label.text[[1]] <- NULL
-
+  
   ## convert keywords into summary placement coordinates
   if(missing(summary.pos) == TRUE) {
     summary.pos <- c(xlim.plot[1], ylim.plot[2])
@@ -602,7 +602,7 @@ plot_Histogram <- function(
     summary.pos <- c(xlim.plot[2], ylim.plot[1])
     summary.adj <- c(1, 0)
   }
-
+  
   ## add summary content
   for(i in 1:length(data.stats)) {
     if(summary.pos[1] != "sub") {
@@ -622,16 +622,16 @@ plot_Histogram <- function(
       }
     }
   }
-
+  
   ## Optionally, add standard error plot --------------------------------------
   if(sum(is.na(data[,2])) == length(data[,2])) {
     se <- FALSE
   }
-
+  
   if(se == TRUE) {
     par(new = TRUE)
     plot.data <- data[!is.na(data[,2]),]
-
+    
     plot(x = plot.data[,1],
          y = plot.data[,2],
          xlim = xlim.plot,
@@ -652,17 +652,17 @@ plot_Histogram <- function(
           side = 4,
           line = 3,
           cex = cex.global)
-
+    
     #    par(new = FALSE)
   }
-
+  
   ## Optionally add user-defined mtext
   mtext(side = 3,
         line = 0.5,
         text = mtext,
         cex = 0.8 * cex.global)
-
+  
   ## FUN by R Luminescence Team
   if(fun==TRUE){sTeve()}
-
+  
 }
