@@ -49,18 +49,26 @@
 #' values based on values delivered by the heating element, it may happen that
 #' mutiple count values exists for each temperature value and temperature
 #' values may also decrease during heating, not only increase. }
+
 #'
 #' @param file \link{character} (\bold{required}): path and file name of the
 #' XSYG file.
+#'
 #' @param recalculate.TL.curves \link{logical} (with default): if set to
 #' \code{TRUE}, TL curves are returned as temperature against count values (see
 #' details for more information) Note: The option overwrites the time vs. count
 #' TL curve. Select \code{FALSE} to import the raw data delivered by the
 #' lexsyg. Works for TL curves and spectra.
+#'
+#' @param fastForward \code{\link{logical}} (with default): if \code{TRUE} for a
+#' more efficient data processing only a list of \code{RLum.Analysis} objects is returned.
+#'
 #' @param import \link{logical} (with default): if set to \code{FALSE}, only
 #' the XSYG file structure is shown.
+#'
 #' @param txtProgressBar \link{logical} (with default): enables \code{TRUE} or
 #' disables \code{FALSE} the progression bar during import
+#'
 #' @return \bold{Using the option \code{import = FALSE}}\cr\cr A list
 #' consisting of two elements is shown: \item{Sample}{\link{data.frame} with
 #' information on file.} \item{Sequences}{\link{data.frame} with information on
@@ -69,21 +77,35 @@
 #' contain: \item{Sequence.Header}{\link{data.frame} with information on the
 #' sequence.} \item{Sequence.Object}{\code{\linkS4class{RLum.Analysis}}
 #' containing the curves.}
+#'
 #' @note This function is a beta version as the XSYG file format is not yet
 #' fully specified. Thus, further file operations (merge, export, write) should
 #' be done using the functions provided with the package \code{\link{xml}}.\cr
 #'
 #' \bold{So far, no image data import is provided!}\cr Corresponding values in
 #' the XSXG file are skipped.
-#' @section Function version: 0.4.3
+#'
+#'
+#' @section Function version: 0.4.5
+#'
+#'
 #' @author Sebastian Kreutzer, IRAMAT-CRP2A, Universite Bordeaux Montaigne
 #' (France)
+#'
+#'
 #' @seealso \code{\link{xml}}, \code{\linkS4class{RLum.Analysis}},
 #' \code{\linkS4class{RLum.Data.Curve}}, \code{\link{approx}}
+#'
+#'
 #' @references Grehl, S., Kreutzer, S., Hoehne, M., 2013. Documentation of the
 #' XSYG file format. Unpublished Technical Note. Freiberg, Germany \cr\cr
+#'
 #' \bold{Further reading} \cr\cr XML: \url{http://en.wikipedia.org/wiki/XML}
+#'
+#'
 #' @keywords IO
+#'
+#'
 #' @examples
 #'
 #'
@@ -97,7 +119,7 @@
 #'
 #'   ##import entire XML file
 #'   #FILE <- file.choose()
-#'   #temp <- xmlRoot(xmlTreeParse(FILE))
+#'   #temp <- XML::xmlRoot(XML::xmlTreeParse(FILE))
 #'
 #'   ##search for specific subnodes with curves containing 'OSL'
 #'   #getNodeSet(temp, "//Sample/Sequence/Record[@@recordType = 'OSL']/Curve")
@@ -106,16 +128,17 @@
 #' data(ExampleData.XSYG, envir = environment())
 #'
 #' ##grep one OSL curves and plot the first curve
-#' OSLcurve <- get_RLum.Analysis(OSL.SARMeasurement$Sequence.Object, recordType="OSL")[[1]]
+#' OSLcurve <- get_RLum(OSL.SARMeasurement$Sequence.Object, recordType="OSL")[[1]]
 #'
 #' ##(3) How to see the structure of an object?
-#' get_structure.RLum.Analysis(OSL.SARMeasurement$Sequence.Object)
+#' structure_RLum(OSL.SARMeasurement$Sequence.Object)
 #'
 #'
 #'
 readXSYG2R <- function(
   file,
   recalculate.TL.curves = TRUE,
+  fastForward = FALSE,
   import = TRUE,
   txtProgressBar = TRUE
 ){
@@ -132,7 +155,7 @@ readXSYG2R <- function(
 
   ##check if file is XML file
   if(tail(unlist(strsplit(file, split = "\\.")), 1) != "xsyg" &
-       tail(unlist(strsplit(file, split = "\\.")), 1) != "XSYG" ){
+     tail(unlist(strsplit(file, split = "\\.")), 1) != "XSYG" ){
 
     stop("[readXSYG2R()] File is not of type 'XSYG'!")
 
@@ -146,7 +169,7 @@ readXSYG2R <- function(
   get_XSYG.curve.values <- function(curve.node){
 
     ##1st string split
-    curve.node <- unlist(strsplit(xmlValue(curve.node), ";"))
+    curve.node <- unlist(strsplit(XML::xmlValue(curve.node), ";"))
 
     ##2nd string split
     curve.node <- as.numeric(unlist(strsplit(curve.node,"[:,:]")))
@@ -159,13 +182,13 @@ readXSYG2R <- function(
   get_XSYG.spectrum.values <- function(curve.node){
 
     ##1st grep wavelength table
-    wavelength <- xmlAttrs(curve.node)["wavelengthTable"]
+    wavelength <- XML::xmlAttrs(curve.node)["wavelengthTable"]
 
     ##string split
     wavelength <- as.numeric(unlist(strsplit(wavelength, ";")))
 
     ##2nd grep time values
-    curve.node <- unlist(strsplit(xmlValue(curve.node), ";"))
+    curve.node <- unlist(strsplit(XML::xmlValue(curve.node), ";"))
     curve.node <- unlist(strsplit(curve.node, ","), recursive = FALSE)
 
     curve.node.time <- as.numeric(curve.node[seq(1,length(curve.node),2)])
@@ -199,7 +222,7 @@ readXSYG2R <- function(
   # (1) Integrity tests -----------------------------------------------------
 
   ##parse XML tree using the package XML
-  temp <- try(xmlRoot(xmlTreeParse(file, useInternalNodes = TRUE)), silent = TRUE)
+  temp <- try(XML::xmlRoot(XML::xmlTreeParse(file, useInternalNodes = TRUE)), silent = TRUE)
 
 
 
@@ -217,20 +240,21 @@ readXSYG2R <- function(
   if(import == FALSE){
 
     ##sample information
-    temp.sample <- as.data.frame(xmlAttrs(temp))
+    temp.sample <- as.data.frame(XML::xmlAttrs(temp))
     colnames(temp.sample) <- ""
 
     ##grep sequences files
 
     ##set data.frame
-    temp.sequence.header <- data.frame(t(1:length(names(xmlAttrs(temp[[1]])))))
+    temp.sequence.header <- data.frame(t(1:length(names(XML::xmlAttrs(temp[[1]])))),
+                                       stringsAsFactors = FALSE)
 
-    colnames(temp.sequence.header) <- names(xmlAttrs(temp[[1]]))
+    colnames(temp.sequence.header) <- names(XML::xmlAttrs(temp[[1]]))
 
     ##fill information in data.frame
-    for(i in 1:xmlSize(temp)){
+    for(i in 1:XML::xmlSize(temp)){
 
-      temp.sequence.header[i,] <- t(xmlAttrs(temp[[i]]))
+      temp.sequence.header[i,] <- t(XML::xmlAttrs(temp[[i]]))
 
     }
 
@@ -240,181 +264,186 @@ readXSYG2R <- function(
   }else{
 
 
-  ##==========================================================================##
-  ##IMPORT XSYG FILE
+    ##==========================================================================##
+    ##IMPORT XSYG FILE
 
-  ##Display output
-  cat("[readXSYG2R()]\n")
+    ##Display output
+    cat("[readXSYG2R()]\n")
 
-  ##PROGRESS BAR
-  if(txtProgressBar == TRUE){
-      pb <- txtProgressBar(min=0,max=xmlSize(temp), char = "=", style=3)
-  }
+    ##PROGRESS BAR
+    if(txtProgressBar == TRUE){
+      pb <- txtProgressBar(min=0,max=XML::xmlSize(temp), char = "=", style=3)
+    }
 
-  ##create list
-  output <- list()
+    ##create list
+    output <- list()
 
-  ##loop over the entire sequence by sequence
-  output <- lapply(1:xmlSize(temp), function(x){
+    ##loop over the entire sequence by sequence
+    output <- lapply(1:XML::xmlSize(temp), function(x){
 
-    ##read sequence header
-    temp.sequence.header <- as.data.frame(xmlAttrs(temp[[x]]))
-    colnames(temp.sequence.header) <- ""
+      ##read sequence header
+      temp.sequence.header <- as.data.frame(XML::xmlAttrs(temp[[x]]), stringsAsFactors = FALSE)
+      colnames(temp.sequence.header) <- ""
 
-     ###-----------------------------------------------------------------------
-     ##LOOP
-     ##read records >> records are combined to one RLum.Analysis object
-     temp.sequence.object <- unlist(lapply(1:xmlSize(temp[[x]]), function(i){
+      ###-----------------------------------------------------------------------
+      ##LOOP
+      ##read records >> records are combined to one RLum.Analysis object
+      temp.sequence.object <- unlist(lapply(1:XML::xmlSize(temp[[x]]), function(i){
 
-      ##get recordType
-      temp.sequence.object.recordType <- xmlAttrs(temp[[x]][[i]])["recordType"]
+        ##get recordType
+        temp.sequence.object.recordType <- try(XML::xmlAttrs(temp[[x]][[i]])["recordType"],
+                                               silent = TRUE)
 
-      ##correct record type in depending on the stimulator
-      if(temp.sequence.object.recordType == "OSL"){
+        ##the XSYG file might be broken due to a machine error during the measurement, this
+        ##control flow helps; if a try-error is observed NULL is returned
+        if(!inherits(temp.sequence.object.recordType, "try-error")){
 
-        if(xmlAttrs(temp[[x]][[i]][[
-          xmlSize(temp[[x]][[i]])]])["stimulator"] == "ir_LED_850"){
+        ##correct record type in depending on the stimulator
+        if(temp.sequence.object.recordType == "OSL"){
 
-          temp.sequence.object.recordType  <- "IRSL"
+          if(XML::xmlAttrs(temp[[x]][[i]][[
+            XML::xmlSize(temp[[x]][[i]])]])["stimulator"] == "ir_LED_850"){
+
+            temp.sequence.object.recordType  <- "IRSL"
+
+          }
 
         }
 
-      }
+
+        ##loop 3rd level
+        lapply(1:XML::xmlSize(temp[[x]][[i]]), function(j){
+
+          ##get values
+          temp.sequence.object.curveValue <- temp[[x]][[i]][[j]]
+
+          ##get curveType
+          temp.sequence.object.curveType <- as.character(
+            XML::xmlAttrs(temp[[x]][[i]][[j]])["curveType"])
+
+          ##get detector
+          temp.sequence.object.detector <- as.character(
+            XML::xmlAttrs(temp[[x]][[i]][[j]])["detector"])
 
 
-       ##loop 3rd level
-       lapply(1:xmlSize(temp[[x]][[i]]), function(j){
-
-         ##get values
-         temp.sequence.object.curveValue <- temp[[x]][[i]][[j]]
-
-         ##get curveType
-         temp.sequence.object.curveType <- as.character(
-           xmlAttrs(temp[[x]][[i]][[j]])["curveType"])
-
-         ##get detector
-         temp.sequence.object.detector <- as.character(
-           xmlAttrs(temp[[x]][[i]][[j]])["detector"])
+          ##get stimulator
+          temp.sequence.object.stimulator <- as.character(
+            XML::xmlAttrs(temp[[x]][[i]][[j]])["stimulator"])
 
 
-         ##get stimulator
-         temp.sequence.object.stimulator <- as.character(
-           xmlAttrs(temp[[x]][[i]][[j]])["stimulator"])
+          ##get parentID
+          temp.sequence.object.parentID <- as.numeric(
+            XML::xmlAttrs(temp[[x]][[i]][[j]])["partentID"])
 
+          ##get additional information
+          temp.sequence.object.info <- as.list(XML::xmlAttrs(temp.sequence.object.curveValue))
 
-         ##get parentID
-         temp.sequence.object.parentID <- as.numeric(
-           xmlAttrs(temp[[x]][[i]][[j]])["partentID"])
-
-         ##get additional information
-         temp.sequence.object.info <- as.list(xmlAttrs(temp.sequence.object.curveValue))
-
-         ##add stimulator and detector and so on
-         temp.sequence.object.info <- c(temp.sequence.object.info,
-                                        detector = temp.sequence.object.detector,
-                                        stimulator = temp.sequence.object.stimulator,
-                                        partentID = temp.sequence.object.parentID,
-                                        position = as.integer(as.character(temp.sequence.header["position",])),
-                                        name = as.character(temp.sequence.header["name",]))
+          ##add stimulator and detector and so on
+          temp.sequence.object.info <- c(temp.sequence.object.info,
+                                         detector = temp.sequence.object.detector,
+                                         stimulator = temp.sequence.object.stimulator,
+                                         partentID = temp.sequence.object.parentID,
+                                         position = as.integer(as.character(temp.sequence.header["position",])),
+                                         name = as.character(temp.sequence.header["name",]))
 
 
 
 
-         ## TL curve recalculation ============================================
-         if(recalculate.TL.curves == TRUE){
+          ## TL curve recalculation ============================================
+          if(recalculate.TL.curves == TRUE){
 
-         ##TL curve heating values is stored in the 3rd curve of every set
-         if(temp.sequence.object.recordType == "TL" && j == 1){
+            ##TL curve heating values is stored in the 3rd curve of every set
+            if(temp.sequence.object.recordType == "TL" && j == 1){
 
-            #grep values from PMT measurement or spectrometer
-            if("Spectrometer" %in% temp.sequence.object.detector == FALSE){
+              #grep values from PMT measurement or spectrometer
+              if("Spectrometer" %in% temp.sequence.object.detector == FALSE){
 
-             temp.sequence.object.curveValue.PMT <- get_XSYG.curve.values(
-                temp[[x]][[i]][[j]])
+                temp.sequence.object.curveValue.PMT <- get_XSYG.curve.values(
+                  temp[[x]][[i]][[j]])
 
 
-             ##round values (1 digit is technical resolution of the heating element)
-             temp.sequence.object.curveValue.PMT[,1] <- round(
-               temp.sequence.object.curveValue.PMT[,1], digits = 1)
+                ##round values (1 digit is technical resolution of the heating element)
+                temp.sequence.object.curveValue.PMT[,1] <- round(
+                  temp.sequence.object.curveValue.PMT[,1], digits = 1)
 
-             #grep values from heating element
-             temp.sequence.object.curveValue.heating.element <- get_XSYG.curve.values(
-                 temp[[x]][[i]][[3]])
+                #grep values from heating element
+                temp.sequence.object.curveValue.heating.element <- get_XSYG.curve.values(
+                  temp[[x]][[i]][[3]])
 
 
 
-            }else{
+              }else{
 
-              temp.sequence.object.curveValue.spectrum <- get_XSYG.spectrum.values(
-                temp.sequence.object.curveValue)
+                temp.sequence.object.curveValue.spectrum <- get_XSYG.spectrum.values(
+                  temp.sequence.object.curveValue)
 
-              ##get time values which are stored in the row labels
-              temp.sequence.object.curveValue.spectrum.time <- as.numeric(
-                colnames(temp.sequence.object.curveValue.spectrum))
+                ##get time values which are stored in the row labels
+                temp.sequence.object.curveValue.spectrum.time <- as.numeric(
+                  colnames(temp.sequence.object.curveValue.spectrum))
 
-              ##round values (1 digit is technical resolution of the heating element)
-              temp.sequence.object.curveValue.spectrum.time <- round(
-                temp.sequence.object.curveValue.spectrum.time, digits = 1)
+                ##round values (1 digit is technical resolution of the heating element)
+                temp.sequence.object.curveValue.spectrum.time <- round(
+                  temp.sequence.object.curveValue.spectrum.time, digits = 1)
 
-            }
+              }
 
-            #grep values from heating element
-            temp.sequence.object.curveValue.heating.element <- get_XSYG.curve.values(
-              temp[[x]][[i]][[3]])
+              #grep values from heating element
+              temp.sequence.object.curveValue.heating.element <- get_XSYG.curve.values(
+                temp[[x]][[i]][[3]])
 
 
-            if("Spectrometer" %in% temp.sequence.object.detector == FALSE){
+              if("Spectrometer" %in% temp.sequence.object.detector == FALSE){
 
-             #reduce matrix values to values of the detection
-             temp.sequence.object.curveValue.heating.element <-
-              temp.sequence.object.curveValue.heating.element[
-                temp.sequence.object.curveValue.heating.element[,1] >=
-                  min(temp.sequence.object.curveValue.PMT[,1]) &
-                temp.sequence.object.curveValue.heating.element[,1] <=
-                  max(temp.sequence.object.curveValue.PMT[,1]),]
+                #reduce matrix values to values of the detection
+                temp.sequence.object.curveValue.heating.element <-
+                  temp.sequence.object.curveValue.heating.element[
+                    temp.sequence.object.curveValue.heating.element[,1] >=
+                      min(temp.sequence.object.curveValue.PMT[,1]) &
+                      temp.sequence.object.curveValue.heating.element[,1] <=
+                      max(temp.sequence.object.curveValue.PMT[,1]),]
 
-             }else{
+              }else{
 
-               #reduce matrix values to values of the detection
-               temp.sequence.object.curveValue.heating.element <-
-                 temp.sequence.object.curveValue.heating.element[
-                   temp.sequence.object.curveValue.heating.element[,1] >=
-                     min(temp.sequence.object.curveValue.spectrum.time) &
-                     temp.sequence.object.curveValue.heating.element[,1] <=
-                     max(temp.sequence.object.curveValue.spectrum.time),]
+                #reduce matrix values to values of the detection
+                temp.sequence.object.curveValue.heating.element <-
+                  temp.sequence.object.curveValue.heating.element[
+                    temp.sequence.object.curveValue.heating.element[,1] >=
+                      min(temp.sequence.object.curveValue.spectrum.time) &
+                      temp.sequence.object.curveValue.heating.element[,1] <=
+                      max(temp.sequence.object.curveValue.spectrum.time),]
 
-            }
+              }
 
 
 
 
-                ## calculate corresponding heating rate, this makes only sense
-                ## for linear heating, therefore is has to be the maximum value
+              ## calculate corresponding heating rate, this makes only sense
+              ## for linear heating, therefore is has to be the maximum value
 
-                ##remove 0 values (not measured) and limit to peak
-                heating.rate.values <- temp.sequence.object.curveValue.heating.element[
-                  temp.sequence.object.curveValue.heating.element[,2] > 0 &
+              ##remove 0 values (not measured) and limit to peak
+              heating.rate.values <- temp.sequence.object.curveValue.heating.element[
+                temp.sequence.object.curveValue.heating.element[,2] > 0 &
                   temp.sequence.object.curveValue.heating.element[,2] <=
-                    max(temp.sequence.object.curveValue.heating.element[,2]),]
+                  max(temp.sequence.object.curveValue.heating.element[,2]),]
 
-                heating.rate <- (heating.rate.values[length(heating.rate.values[,2]), 2] -
+              heating.rate <- (heating.rate.values[length(heating.rate.values[,2]), 2] -
                                  heating.rate.values[1,2])/
-                                (heating.rate.values[length(heating.rate.values[,1]), 1] -
-                                 heating.rate.values[1,1])
+                (heating.rate.values[length(heating.rate.values[,1]), 1] -
+                   heating.rate.values[1,1])
 
 
-                ##round values
-                heating.rate <- round(heating.rate, digits=1)
+              ##round values
+              heating.rate <- round(heating.rate, digits=1)
 
-                ##add to info element
-                temp.sequence.object.info <- c(temp.sequence.object.info,
-                                               RATE = heating.rate)
+              ##add to info element
+              temp.sequence.object.info <- c(temp.sequence.object.info,
+                                             RATE = heating.rate)
 
 
-                ##PERFORM RECALCULATION
-                ##check which object contains more data
+              ##PERFORM RECALCULATION
+              ##check which object contains more data
 
-                if("Spectrometer" %in% temp.sequence.object.detector == FALSE){
+              if("Spectrometer" %in% temp.sequence.object.detector == FALSE){
 
                 ##CASE (1)
                 if(nrow(temp.sequence.object.curveValue.PMT) >
@@ -426,13 +455,13 @@ readXSYG2R <- function(
                     xout = temp.sequence.object.curveValue.PMT[,1],
                     rule = 2)
 
-                    temperature.values <-
-                      temp.sequence.object.curveValue.heating.element.i$y
+                  temperature.values <-
+                    temp.sequence.object.curveValue.heating.element.i$y
 
-                    count.values <-
-                      temp.sequence.object.curveValue.PMT[,2]
+                  count.values <-
+                    temp.sequence.object.curveValue.PMT[,2]
 
-                ##CASE (2)
+                  ##CASE (2)
                 }else if((nrow(temp.sequence.object.curveValue.PMT) <
                           nrow(temp.sequence.object.curveValue.heating.element))){
 
@@ -447,7 +476,7 @@ readXSYG2R <- function(
 
                   count.values <- temp.sequence.object.curveValue.PMT.i$y
 
-                ##CASE (3)
+                  ##CASE (3)
                 }else{
 
                   temperature.values <-
@@ -474,7 +503,7 @@ readXSYG2R <- function(
                 ##         take care of noise later one
 
                 if(length(temp.sequence.object.curveValue.spectrum.time) !=
-                     nrow(temp.sequence.object.curveValue.heating.element)){
+                   nrow(temp.sequence.object.curveValue.heating.element)){
 
                   temp.sequence.object.curveValue.heating.element.i <- approx(
                     x = temp.sequence.object.curveValue.heating.element[,1],
@@ -499,7 +528,7 @@ readXSYG2R <- function(
 
 
 
-                ##CASE (2)  (equal)
+                  ##CASE (2)  (equal)
                 }else{
 
                   temperature.values <-
@@ -519,12 +548,12 @@ readXSYG2R <- function(
 
 
 
-          }##endif
-         }##endif recalculate.TL.curves == TRUE
+            }##endif
+          }##endif recalculate.TL.curves == TRUE
 
 
-         ##Set RLum.Data objects
-         if("Spectrometer" %in% temp.sequence.object.detector == FALSE){
+          ##Set RLum.Data objects
+          if("Spectrometer" %in% temp.sequence.object.detector == FALSE){
 
             if(is(temp.sequence.object.curveValue, "matrix") == FALSE){
 
@@ -534,67 +563,103 @@ readXSYG2R <- function(
             }
 
 
-         set_RLum.Data.Curve(recordType = paste(temp.sequence.object.recordType,
-                                                " (", temp.sequence.object.detector,")",
-                                                sep = ""),
-                    curveType = temp.sequence.object.curveType,
-                    data = temp.sequence.object.curveValue,
-                    info = temp.sequence.object.info)
+            set_RLum(
+              class = "RLum.Data.Curve",
+              recordType = paste(temp.sequence.object.recordType,
+                                 " (", temp.sequence.object.detector,")",
+                                 sep = ""),
+              curveType = temp.sequence.object.curveType,
+              data = temp.sequence.object.curveValue,
+              info = temp.sequence.object.info)
 
-         }else if("Spectrometer" %in% temp.sequence.object.detector == TRUE) {
+          }else if("Spectrometer" %in% temp.sequence.object.detector == TRUE) {
 
 
-           if(is(temp.sequence.object.curveValue, "matrix") == FALSE){
+            if(is(temp.sequence.object.curveValue, "matrix") == FALSE){
 
-             temp.sequence.object.curveValue <-
-               get_XSYG.spectrum.values(temp.sequence.object.curveValue)
+              temp.sequence.object.curveValue <-
+                get_XSYG.spectrum.values(temp.sequence.object.curveValue)
 
-           }
+            }
 
 
-           set_RLum.Data.Spectrum(recordType = paste(temp.sequence.object.recordType,
-                                                  " (",temp.sequence.object.detector,")",
-                                                  sep = ""),
-                               curveType = temp.sequence.object.curveType,
-                               data = temp.sequence.object.curveValue,
-                               info = temp.sequence.object.info)
+            set_RLum(
+              class = "RLum.Data.Spectrum",
+              recordType = paste(temp.sequence.object.recordType,
+                                 " (",temp.sequence.object.detector,")",
+                                 sep = ""),
+              curveType = temp.sequence.object.curveType,
+              data = temp.sequence.object.curveValue,
+              info = temp.sequence.object.info)
 
-         }
+          }
 
-       })
+        })
+
+        }else{
+
+         return(NULL)
+
+        }##if-try condition
+
+      }))
 
 
-     }))
-
-     ##set RLum.Analysis object
-     temp.sequence.object <-  set_RLum.Analysis(
-                                records = temp.sequence.object,
-                                protocol = as.character(
-                                temp.sequence.header["protocol",1]))
+      ##if the XSYG file is broken we get NULL as list element
+      if (!is.null(temp.sequence.object)) {
+        ##set RLum.Analysis object
+        temp.sequence.object <-  set_RLum(
+          class = "RLum.Analysis",
+          records = temp.sequence.object,
+          protocol = as.character(temp.sequence.header["protocol",1])
+        )
 
 
-    ##update progress bar
-    if(txtProgressBar == TRUE){
-      setTxtProgressBar(pb, x)
+        ##update progress bar
+        if (txtProgressBar == TRUE) {
+          setTxtProgressBar(pb, x)
+        }
+
+
+        ##merge output and return values
+        if(fastForward){
+          return(temp.sequence.object)
+
+        }else{
+          return(list(Sequence.Header = temp.sequence.header, Sequence.Object = temp.sequence.object))
+
+        }
+
+      }else{
+        return(temp.sequence.object)
+
+      }
+
+    })##end loop for sequence list
+
+    ##close ProgressBar
+    if(txtProgressBar == TRUE){close(pb)}
+
+    ##show output informatioj
+    if(length(output[sapply(output, is.null)]) == 0){
+
+      cat(paste("\t >>",XML::xmlSize(temp), " sequence(s) loaded successfully.\n"), sep = "")
+
+    }else{
+
+      cat(paste("\t >>",XML::xmlSize(temp), " sequence(s) in file.",
+                XML::xmlSize(temp)-length(output[sapply(output, is.null)]), "sequence(s) loaded successfully. \n"), sep = "")
+
+      warning(paste0(length(output[sapply(output, is.null)])), " incomplete sequence(s) removed.")
+
     }
 
-
-    ##merge output
-    temp.output <- list(Sequence.Header = temp.sequence.header,
-                        Sequence.Object = temp.sequence.object)
-
-
-
-  })##end loop for sequence
-
-  ##close ProgressBar
-  if(txtProgressBar == TRUE){close(pb)}
-
-  cat(paste("\t >>",xmlSize(temp), " sequence(s) loaded successfully.\n"), sep = "")
-
-  ##output
-  invisible(output)
+    ##output
+    invisible(output)
 
   }#end if
 
+  ##get rid of the NULL elementsn (as stated before ... invalid files)
+  return(output[!sapply(output,is.null)])
+
 }
